function reinitializeSimulator(this)
    %% PHYSICAL CONSTANTS
    pc = Helper.PhysicsConstants;
    %% SIMULATION PARAMETERS
    this.NozzleLength         = 60e-3;
    this.NozzleRadius         = 2.50e-3;
    this.Beta                 = 2 * (this.NozzleRadius/this.NozzleLength); 
    this.ApertureCut          = max(2.5e-3,this.NozzleRadius);
    this.OvenDistance         = (25+12.5)*1e-3 + (this.NozzleRadius + this.ApertureCut) / tan(15/360 * 2 * pi);
    % Distance between the nozzle and the 2-D MOT chamber center
    % 25 is the beam radius/sqrt(2)
    % 12.5 is the radius of the oven
    % 15 eg is the angle between the 2-D MOT chamber center and the nozzle
    this.OvenTemperature      = 1000;  % Temperature in Celsius
    this.MOTDistance          = 320e-3; % Distance between the 2-D MOT the 3-D MOT  
    this.BlueWaveVector       = 2*pi/pc.BlueWavelength;
    this.BlueSaturationIntensity = 2*pi^2*pc.PlanckConstantReduced*pc.SpeedOfLight*pc.BlueLinewidth/3/(pc.BlueWavelength)^3/10;
    this.OrangeWaveVector     = 2*pi/pc.OrangeWavelength;
    this.OrangeSaturationIntensity = 2*pi^2*pc.PlanckConstantReduced*pc.SpeedOfLight*pc.OrangeLinewidth/3/(pc.OrangeWavelength)^3/10;
    this.BlueBeamRadius       = min(0.035/2,sqrt(2)/2*this.OvenDistance); % Diameter of CF40 flange = 0.035
    Theta_Nozzle              = atan((this.NozzleRadius+this.BlueBeamRadius*sqrt(2))/this.OvenDistance); % The angle of capture region towards the oven nozzle
    Theta_Aperture            = 15/360*2*pi; % The limitation angle of the second aperture in the oven
    this.NozzleExitDivergence = min(Theta_Nozzle,Theta_Aperture); 
    this.MOTExitDivergence    = 0.016; % The limitation angle between 2D-MOT and 3D-MOT
    this.TotalPower           = 0.4;
    this.OrangeBeamRadius     = 1.2e-03;
    this.PushBeamRadius       = 0.000;
    this.PushBeamDistance     = 0.32;
    this.DistanceBetweenPushBeamAnd3DMOTCenter = 0;
    this.ZeemanSlowerBeamRadius                = 1;
end